////////////////////////////////////////////////////////////////////////////////
//
// Workfile   : Fex21API.h
// Project    : fex21 Custom Capabilities API
// Copyright  : Copyright (c) 1998,1999 WPI Husky Technology Ltd.
// Description: Interface file to Fex21API.DLL low level utilities.
//

/* Make sure this file is only included once */
#ifndef FEX21API_H
#define FEX21API_H


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#ifndef _WINDOWS_

#ifndef STRICT
#define STRICT 1
#endif /* STRICT */

/* Disable windows.h level 4 compiler warnings */
#ifdef _MSC_VER                 
#pragma warning(disable: 4514)  /*  unreferenced inlines are common           */
#pragma warning(disable: 4115)  /*  named type definition in parentheses      */
#pragma warning(disable: 4201)  /*  nameless structs                          */
#pragma warning(disable: 4214)  /*  bit field types other than int            */
#pragma warning(disable: 4052)  /*  different func declarations (CE, kfuncs.h)*/
#endif /* _MSC_VER */

#include <windows.h>

/* Restore warnings, except 4514 */
#ifdef _MSC_VER                 
#pragma warning(default: 4052)
#pragma warning(default: 4214)
#pragma warning(default: 4201)
#pragma warning(default: 4115)
#endif /* _MSC_VER */

#endif /* !_WINDOWS_ */


/* Define DLL import modifier */
#ifndef ISISAPI

#ifdef ISIS_USE_STATIC
#define ISISAPI
#else /* !ISIS_USE_STATIC */
#ifdef _MSC_VER
#define ISISAPI __declspec(dllimport)
#else /* !_MSC_VER */
#define ISISAPI
#endif /* _MSC_VER */
#endif /* ISIS_USE_STATIC */

#ifdef _MSC_VER
#ifdef ISIS_USE_STATIC
        #pragma comment(lib, "fex21apis.lib")
#else /* !ISIS_USE_STATIC */
        #pragma comment(lib, "fex21api.lib")
#endif /* ISIS_USE_STATIC */
#endif /* _MSC_VER */

#endif /* !ISISAPI */


/*********************/
/* STRUCTURE PACKING */
/*********************/

/* Change structure packing so all fields fall on 1byte boundaries */
#ifndef ISIS_PACKING
#define ISIS_PACKING 1          /* Structure member alignment for module      */
#endif /* !ISIS_PACKING */

#ifdef ISIS_PACKING
#ifdef _MSC_VER
#pragma pack(push, ISIS_PACKING)
#else /* !_MSC_VER */
#pragma pack(ISIS_PACKING)
#endif /* _MSC_VER */
#endif /* ISIS_PACKING */

/***********/
/* DEFINES */
/***********/

/* Number of country code Keyboard variants */
#define MAX_LAYOUT_IDX  6

/* ISISBATTERYSTATUS bit field values   */
#define IBS_STANDBYNOTKNOWN 0x00/* Standby battery status 00 Not Known        */
#define IBS_STANDBYCRITICAL 0x01/*                        01 Critical         */
#define IBS_STANDBYLOW      0x02/*                        10 Low              */
#define IBS_STANDBYHIGH     0x03/*                        11 High             */

#define IBS_CHANGED         0x01/* Main battery changed since last read       */

#define IBS_FAULT           0x01/* Main battery fault (smart battery only)    */

#define IBS_SMART           0x01/* Smart main battery (else alkaline)         */

#define IBS_MAINNOTKNOWN    0x00/* Main battery ststus 000 Not Known          */
#define IBS_MAINCRITICAL    0x01/*                     001 Critical           */
#define IBS_MAINLOW         0x02/*                     010 Low                */
#define IBS_MAINHIGH        0x03/*                     011 High               */
#define IBS_MAINCHARGING    0x04/*                     100 Charging           */
#define IBS_MAINNKWAKEUP    0x05/*                     101 Not known (wakeup) */
#define IBS_MAINRESERVED    0x06/*                     110 Reserved           */
#define IBS_MAINNOBATTERY   0x07/*                     111 No Battery         */

/* Backup RTC status bits */
#define RTC_DATAOK          0x02    /* Data valid and will be written to RTC */

/* Data buffer maximum sizes */
#define NV_RAM_BLOCK_SIZE   16          /* Number of bytes per NVRAM block */
#define NV_RAM_SERNO_SIZE   10          /* Max chars in serial number excl. NULL terminator */
#define NV_RAM_SERNO_OFFSET (NV_RAM_BLOCK_SIZE-NV_RAM_SERNO_SIZE)
#define NV_RAM_KEYBD_OFFSET 2           /* Position of default keyboard index byte in nvRAM block 0 */


/**************/
/* STRUCTURES */
/**************/

/* The following structures use C bitfields to identify the      */
/* fields within the raw data blocks returned by the system.     */

/* This structure is used to determine the status of the battery */
/* See also: psuGetBatteryStatus()                               */

typedef struct tagISISBATTERYSTATUS
{
    WORD StdByStat      : 2;        /* Standby battery status                      */
    WORD BatChgd        : 1;        /* Battery changed flag                        */
    WORD BatFault       : 1;        /* Smart battery fault detected flag           */
    WORD BatType        : 1;        /* Battery type 1=Smart, 0=Not smart           */
    WORD BatStat        : 3;        /* Smart battery status (see IBS_MAIN defines) */
    WORD BatLife        : 7;        /* % remaining or 127 if unknown               */
    WORD ChrgConn       : 1;        /* Charger connected flag                      */
    WORD CapLeft        : 14;       /* Estimated mAh remaining (0x3FFF if unknown) */
    WORD CapUnreliable  : 1;        /* CapLeft unreliable flag                     */
    WORD ChrgOk         : 1;        /* Charging allowed if smart battery fitted    */
} ISISBATTERYSTATUS, *PISISBATTERYSTATUS;


/* This structure is used to retrieve further information about  */
/* the smart battery and any detected faults                     */
/* See also: psuGetBatteryInfo()                                 */

typedef struct tagISISBATTERYINFO
{
    WORD Reserved0      : 8;        /* 1 padding BYTE for bit field alignment      */

    /* The next 8 fields are diagnostic/error detection flags            */
    /* If SmBatFitted is 0 all other diagnostic fields should be ignored */
    /* If EPROMOk is 0 ALL other fields should be considered unreliable  */
    /* If ChargingOk is 0 charging has been aborted and the unit should  */
    /*  be disconected and resarted.                                     */
    /* If TempOk is 0 TherRng indicates the range violation direction    */
    /* If TherOk is 0 TherRng indicates the range violation and TempOk   */
    /*  should be considered invalid                                     */

    WORD ChargingOk     : 1;        /* Charging Ok flag (0 indicates fault)        */
    WORD TherRng        : 1;        /* Charging fault range range (0=low, 1=high)  */
    WORD TherOk         : 1;        /* Thermistor ok flag                          */
    WORD TempOk         : 1;        /* Temperature ok flag                         */
    WORD EPROMOk        : 1;        /* E2PROM answering and ID CRC Ok flag         */
    WORD GasGgeOk       : 1;        /* Gas guage answering with valid values flag  */
    WORD BatteryOk      : 1;        /* AND of previous flags                       */
    WORD SmBatFitted    : 1;        /* Smart battery detected flag                 */

    /* The next 7 fields can be used to uniquely identify the battery */
    /* Unique battery identifier consists of serial number + date     */
    /* I.e.: 189 23 10 98 (where the year is an offset from 1900 AD)  */
    WORD SerNo          : 8;        /* Daily serial number (0-255 )   */
    WORD DayOfMan       : 5;        /* Day of month of manufacture    */
    WORD Reserved1      : 3;
    WORD MonOfMan       : 4;        /* Month of manufacture (1-12)    */
    WORD Revision       : 2;        /* Battery build revision         */
    WORD Chemistry      : 2;        /* 0=NiCad, 1=NiMH, 2=LiIon       */
    WORD YearOfMan      : 8;        /* Year of manufacture            */

    /* The remaining fields describe the current charge state of the battery */
    /* ChrgCycls holds the number of full charge cycles and is 0 if   */
    /* this value is unknown.  If more than 8190 cycles have been     */
    /* performed this will be 8191 and the battery should be replaced */
    /* If EPROMCRCOk is 0 ChrgCycls should be considered unreliable   */
    WORD Capacity       : 16;       /* Manufacture's quoted capacity  */
    WORD ChrgCycls      : 12;       /* Number of charge cycles        */
    WORD Reserved3      : 3;
    WORD EPROMCRCOk     : 1;        /* 0=E2PROM could be corrupt      */
} ISISBATTERYINFO, *PISISBATTERYINFO;


/* This structure is used to read and change the current status  */
/* of the backlight and its timeout settings                     */
/* See also: lcdGetBacklight(), lcdSetBacklight()                */

typedef struct tagISISBACKLIGHT
{
    /* The first two fields represent the auto dim timeout status   */
    /* TimeoutVal is 0 if timeouts are disabled else this value is  */
    /* gives the duration of inactivity, after which the backlight  */
    /* will auto-dim, in 30s intervals                              */
    /* If Timeout Mode is 1 auto-dim will occur after TimeoutVal    */
    /* whether or not there is any activity.  If it is 2 auto-dim   */
    /* will occur only if the unit is inactive, pen or keyboard     */
    /* activity will reset the timeout counter.  If it is 3, the    */
    /* auto-dim behaves as for 2, but any activity after timeout    */
    /* will relight the backlight and reset the timeout counter.    */
    WORD TimeoutVal:    4;          /* Initial timeout in 30s periods */
    WORD TimeoutMode:   2;          /* Reset and resume mode for T/O  */
    WORD Reserved3:     2;

    /* The remaining fields describe the current backlight status   */
    /* The Level field is only valid if DisplayType is not 0 (mono) */
    WORD Reserved0:     1;
    WORD Level:         2;          /* Intensity (0-3)                */
    WORD Reserved1:     1;
    WORD DisplayType:   2;          /* 0=mono, 1=Colour, 2=T/R colour */
    WORD LiteState:     1;          /* Backlight on flag              */
    WORD Reserved2:     1;
} ISISBACKLIGHT, *PISISBACKLIGHT;


/* This structure can be used to determine the current version   */
/* of the installed DLL.                                         */
/* See also: dllGetVersion()                                     */

typedef struct tagISISVERSION
{
    BYTE  ReleaseNo;                /* DLL release number               */
    BYTE  MajorVer ;                /* DLL major version number         */
    BYTE  MinorVer ;                /* DLL minor version number         */
    BYTE  Reserved1;
    TCHAR BuildDate[16];            /* DLL build date (Mmm dd yyyy)     */
    BYTE  BootMajVer;               /* Bootloader major version number  */
    BYTE  BootMinVer;               /* Bootloader minor version number  */
} ISISVERSION, *PISISVERSION;


/* This structure is used to set and read the value of the micro-*/
/* controller's backup Real Time Clock (RTC).                    */
/* If this is not set once the values returned by the battery %  */
/* and chanrge remaining functions may be inaccurate due to the  */
/* backup RTC being used to determine self-discharge rates.      */

typedef struct tagISISRTC
{
    WORD    Seconds     : 6;        /* Seconds value (0-59)             */
    WORD    Fault       : 1;        /* Backup RTC fault detected        */
    WORD    BatFlat     : 1;        /* Backup RTC battery has been flat */
    WORD    Minutes     : 6;        /* Minutes value (0-59)             */
    WORD    Reserved1   : 2;

    WORD    Hours       : 5;        /* Hours value (0-23)               */
    WORD    Reserved2   : 3;
    WORD    DayOfMonth  : 5;        /* Day value (1-31)                 */
    WORD    Reserved3   : 3;

    WORD    Month       : 4;        /* Month value (1-12)               */
    WORD    Reserved4   : 4;
    WORD    Year        : 8;        /* Years from 1900 (99-130)         */
} ISISRTC, *PISISRTC;


/* Restore data structure packing to the default */
#ifdef ISIS_PACKING
#ifdef _MSC_VER
#pragma pack(pop)
#else /* !_MSC_VER */
#pragma pack()
#endif /* _MSC_VER */
#endif /* ISIS_PACKING */


/**********************/
/* EXPORTED FUNCTIONS */
/**********************/

ISISAPI BOOL APIENTRY dllGetVersion( PISISVERSION pDllVer );
ISISAPI BOOL APIENTRY spicoderSendBlock(const BYTE* pData,
										DWORD cbData,
										BYTE* pResponse,
										DWORD* pcbResponse);


ISISAPI BOOL APIENTRY keybPowerHandler(BOOL bOff);
ISISAPI BOOL APIENTRY keybReadKeyCode(BYTE* pKeyCode);
ISISAPI BOOL APIENTRY keybInitialise(void);
ISISAPI BOOL APIENTRY keybGetHeartbeat(void);
ISISAPI BOOL APIENTRY keybGetID(BYTE *pbRevision, BYTE *pbBuildNo, BYTE *pbDispTyp);
ISISAPI BOOL APIENTRY keybGetLEDStatus(void);
ISISAPI BOOL APIENTRY keybSetLEDStatus(void);
ISISAPI BOOL APIENTRY keybSetIOMode(void);
ISISAPI BOOL APIENTRY keybSetIOData(void);
ISISAPI BOOL APIENTRY keybSetWakeUpKeys(void);

ISISAPI BOOL APIENTRY keybSetLayout(const TCHAR *szPath);
ISISAPI BOOL APIENTRY keybSetDefault(const DWORD dwIdx);
ISISAPI BOOL APIENTRY keybGetDefault(DWORD *pdwIdx);

ISISAPI BOOL APIENTRY psuGetBatterySerialNo(TCHAR *szStr);
ISISAPI BOOL APIENTRY psuGetBatteryStatus(PISISBATTERYSTATUS pBatteryStatus);
ISISAPI BOOL APIENTRY psuGetBatteryInfo(PISISBATTERYINFO pBatteryInfo);
ISISAPI BOOL APIENTRY psuGetChargingEnabled(PBOOL pEnabled);
ISISAPI BOOL APIENTRY psuEnableCharging(void);
ISISAPI BOOL APIENTRY psuDisableCharging(void);


ISISAPI BOOL APIENTRY lcdGetBacklight(PISISBACKLIGHT pBackLight);
ISISAPI BOOL APIENTRY lcdSetBacklight(PISISBACKLIGHT pBackLight);
ISISAPI BOOL APIENTRY lcdGetContrast(BYTE* bpGetContrastValue);
ISISAPI BOOL APIENTRY lcdSetContrast(BYTE bContrastValue);

	
ISISAPI BOOL APIENTRY nvramReadBlock(DWORD nBlock, BYTE* pData);
ISISAPI BOOL APIENTRY nvramWriteBlock(DWORD nBlock, const BYTE* pData);
ISISAPI BOOL APIENTRY nvramGetSerialNumber(TCHAR *szStr);
ISISAPI BOOL APIENTRY nvramSetSerialNumber(const TCHAR *szStr);


ISISAPI BOOL APIENTRY rtcGetBackup( PISISRTC pRTC );
ISISAPI BOOL APIENTRY rtcSetBackup( PISISRTC pRTC );


ISISAPI BOOL APIENTRY comSetPort1Connection( BOOL bUseMainConnector );
ISISAPI BOOL APIENTRY comSetPort2Connection( BOOL bUseMainConnector );
ISISAPI BOOL APIENTRY comGetPort1Connection( BOOL *pbMainSelected );
ISISAPI BOOL APIENTRY comGetPort2Connection( BOOL *pbMainSelected );
ISISAPI BOOL APIENTRY comSetPort1PowerOut( BOOL bPowerOut );
ISISAPI BOOL APIENTRY comSetPort2PowerOut( BOOL bPowerOut );
ISISAPI BOOL APIENTRY comGetPort1PowerOut( BOOL *pbPowerOut );
ISISAPI BOOL APIENTRY comGetPort2PowerOut( BOOL *pbPowerOut );


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* !FEX21API_H */
